@@ -1,10 +1,13 @@
 package Code::TidyAll;
 
-use Code::TidyAll::Config::INI::Reader;
+use strict;
+use warnings;
+
 use Code::TidyAll::Cache;
 use Code::TidyAll::CacheModel;
-use Code::TidyAll::Util qw(can_load);
+use Code::TidyAll::Config::INI::Reader;
 use Code::TidyAll::Result;
+use Code::TidyAll::Util qw(can_load);
 use Data::Dumper;
 use Date::Format;
 use Digest::SHA qw(sha1_hex);
@@ -12,14 +15,13 @@ use File::Find qw(find);
 use File::Zglob;
 use List::SomeUtils qw(uniq);
 use Path::Tiny qw(path);
-use Moo;
 use Scalar::Util qw(blessed);
 use Time::Duration::Parse qw(parse_duration);
 use Try::Tiny;
-use strict;
-use warnings;
 
-our $VERSION = '0.52';
+use Moo;
+
+our $VERSION = '0.53';
 
 sub default_conf_names { ( 'tidyall.ini', '.tidyallrc' ) }
 
@@ -45,7 +47,7 @@ has 'root_dir'          => ( is => 'ro', required => 1 );
 has 'verbose'           => ( is => 'ro' );
 
 # Internal
-has 'backup_dir'       => ( is => 'lazy', init_arg => undef, trigger => 1 );
+has 'backup_dir'       => ( is => 'lazy', init_arg => undef );
 has 'backup_ttl_secs'  => ( is => 'lazy', init_arg => undef );
 has 'base_sig'         => ( is => 'lazy', init_arg => undef );
 has 'plugin_objects'   => ( is => 'lazy', init_arg => undef );
@@ -348,7 +350,10 @@ sub process_file {
 
         # write new contents out to disk
         $contents = $result->new_contents;
-        path( $full_path . $self->output_suffix )->spew($contents);
+
+        # We don't use ->spew because that creates a new file and renames it,
+        # losing the existing mode setting in the process.
+        path( $full_path . $self->output_suffix )->append( { truncate => 1 }, $contents );
 
         # change the in memory contents of the cache (but don't update yet)
         $cache_model->file_contents($contents) unless $self->output_suffix;
@@ -637,7 +642,7 @@ Code::TidyAll - Engine for tidyall, your all-in-one code tidier and validator
 
 =head1 VERSION
 
-version 0.52
+version 0.53
 
 =head1 SYNOPSIS
 
@@ -842,12 +847,16 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Andy Jack Finn Smith George Hartzell Graham Knop Gregory Oschwald Joe Crotty Mark Fowler Grimes Martin Gruner Mohammad S Anwar Olaf Alders Pedro Melo Ricardo Signes Sergey Romanov timgimyee
+=for stopwords Adam Herzog Andy Jack Finn Smith George Hartzell Graham Knop Gregory Oschwald Joe Crotty Mark Fowler Grimes Martin Gruner Mohammad S Anwar Olaf Alders Pedro Melo Ricardo Signes Sergey Romanov timgimyee
 
 =over 4
 
 =item *
 
+Adam Herzog <adam@adamherzog.com>
+
+=item *
+
 Andy Jack <andyjack@cpan.org>
 
 =item *
