@@ -1,10 +1,14 @@
 package Code::TidyAll::Cache;
 
+use strict;
+use warnings;
+
 use Digest::SHA qw(sha1_hex);
 use Path::Tiny qw(path);
+
 use Moo;
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 
 has 'cache_dir' => ( is => 'ro', required => 1 );
 
