@@ -1,10 +1,14 @@
 package Code::TidyAll::CacheModel;
 
+use strict;
+use warnings;
+
 use Digest::SHA qw(sha1_hex);
 use Path::Tiny ();
+
 use Moo;
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 
 # todo, type checking?
 
@@ -86,7 +90,7 @@ Code::TidyAll::CacheModel - Caching model for Code::TidyAll
 
 =head1 VERSION
 
-version 0.52
+version 0.53
 
 =head1 SYNOPSIS
 
