@@ -1,9 +1,13 @@
 package Code::TidyAll::CacheModel::Shared;
 
+use strict;
+use warnings;
+
 use Moo;
+
 extends 'Code::TidyAll::CacheModel';
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 
 sub _build_cache_key {
     my $self = shift;
@@ -39,7 +43,7 @@ Code::TidyAll::CacheModel::Shared - Shared cache model for Code::TidyAll
 
 =head1 VERSION
 
-version 0.52
+version 0.53
 
 =head1 SYNOPSIS
 
