@@ -1,16 +1,20 @@
 package Code::TidyAll::Git::Precommit;
 
+use strict;
+use warnings;
+
 use Capture::Tiny qw(capture_stdout capture_stderr);
-use Code::TidyAll;
 use Code::TidyAll::Git::Util qw(git_files_to_commit);
+use Code::TidyAll;
 use Guard;
-use Log::Any qw($log);
 use IPC::System::Simple qw(capturex run);
-use Moo;
+use Log::Any qw($log);
 use Path::Tiny qw(path);
 use Try::Tiny;
 
-our $VERSION = '0.52';
+use Moo;
+
+our $VERSION = '0.53';
 
 # Public
 has 'conf_name'       => ( is => 'ro' );
@@ -89,7 +93,7 @@ tidyall'd
 
 =head1 VERSION
 
-version 0.52
+version 0.53
 
 =head1 SYNOPSIS
 
