@@ -1,15 +1,19 @@
 package Code::TidyAll::Git::Prereceive;
 
-use Code::TidyAll;
-use Code::TidyAll::Util qw(tempdir_simple);
+use strict;
+use warnings;
+
 use Capture::Tiny qw(capture);
+use Code::TidyAll::Util qw(tempdir_simple);
+use Code::TidyAll;
 use Digest::SHA qw(sha1_hex);
 use IPC::System::Simple qw(capturex run);
-use Moo;
 use Path::Tiny qw(cwd path);
 use Try::Tiny;
 
-our $VERSION = '0.52';
+use Moo;
+
+our $VERSION = '0.53';
 
 # Public
 has 'allow_repeated_push' => ( is => 'ro', default => 3 );
@@ -164,7 +168,7 @@ tidyall'd
 
 =head1 VERSION
 
-version 0.52
+version 0.53
 
 =head1 SYNOPSIS
 
