@@ -1,14 +1,16 @@
 package Code::TidyAll::Git::Util;
 
+use strict;
+use warnings;
+
 use Code::TidyAll::Util qw(pushd);
 use IPC::System::Simple qw(capturex);
 use List::SomeUtils qw(uniq);
 use Path::Tiny qw(path);
-use strict;
-use warnings;
-use base qw(Exporter);
 
-our $VERSION = '0.52';
+use Exporter qw(import);
+
+our $VERSION = '0.53';
 
 our @EXPORT_OK = qw(git_files_to_commit git_modified_files);
 
