@@ -1,14 +1,17 @@
 package Code::TidyAll::Plugin;
 
+use strict;
+use warnings;
+
 use Code::TidyAll::Util::Zglob qw(zglobs_to_regex);
-use File::Which qw( which );
-use IPC::Run3 qw( run3 );
+use File::Which qw(which);
+use IPC::Run3 qw(run3);
 use Scalar::Util qw(weaken);
-use Text::Diff 1.44 qw( diff );
+use Text::Diff 1.44 qw(diff);
 
 use Moo;
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 
 # External
 has 'argv'               => ( is => 'ro', default => q{} );
@@ -204,7 +207,7 @@ Code::TidyAll::Plugin - Create plugins for tidying or validating code
 
 =head1 VERSION
 
-version 0.52
+version 0.53
 
 =head1 SYNOPSIS
 
