@@ -1,10 +1,15 @@
 package Code::TidyAll::Plugin::CSSUnminifier;
 
+use strict;
+use warnings;
+
 use IPC::System::Simple qw(run);
+
 use Moo;
+
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 
 sub _build_cmd {'cssunminifier'}
 
