@@ -1,11 +1,16 @@
 package Code::TidyAll::Plugin::JSBeautify;
 
+use strict;
+use warnings;
+
 use IPC::Run3 qw(run3);
-use Moo;
 use Try::Tiny;
+
+use Moo;
+
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 
 sub _build_cmd {'js-beautify'}
 
@@ -44,7 +49,7 @@ Code::TidyAll::Plugin::JSBeautify - Use js-beautify with tidyall
 
 =head1 VERSION
 
-version 0.52
+version 0.53
 
 =head1 SYNOPSIS
 
