@@ -1,15 +1,20 @@
 package Code::TidyAll::Plugin::JSHint;
 
+use strict;
+use warnings;
+
 use Code::TidyAll::Util qw(tempdir_simple);
 use IPC::Run3 qw(run3);
+
 use Moo;
+
 extends 'Code::TidyAll::Plugin';
 
 has 'options' => ( is => 'ro', predicate => '_has_options' );
 
 with 'Code::TidyAll::Role::Tempdir';
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 
 sub _build_cmd {'jshint'}
 
@@ -55,7 +60,7 @@ Code::TidyAll::Plugin::JSHint - Use jshint with tidyall
 
 =head1 VERSION
 
-version 0.52
+version 0.53
 
 =head1 SYNOPSIS
 
