@@ -1,12 +1,17 @@
 package Code::TidyAll::Plugin::MasonTidy;
 
+use strict;
+use warnings;
+
 use Mason::Tidy;
 use Mason::Tidy::App;
-use Moo;
 use Text::ParseWords qw(shellwords);
+
+use Moo;
+
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 
 sub _build_cmd {'masontidy'}
 
@@ -35,7 +40,7 @@ Code::TidyAll::Plugin::MasonTidy - Use masontidy with tidyall
 
 =head1 VERSION
 
-version 0.52
+version 0.53
 
 =head1 SYNOPSIS
 
