@@ -1,10 +1,15 @@
 package Code::TidyAll::Plugin::PHPCodeSniffer;
 
+use strict;
+use warnings;
+
 use IPC::Run3;
+
 use Moo;
+
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 
 sub _build_cmd {'phpcs'}
 
@@ -36,7 +41,7 @@ Code::TidyAll::Plugin::PHPCodeSniffer - Use phpcs with tidyall
 
 =head1 VERSION
 
-version 0.52
+version 0.53
 
 =head1 SYNOPSIS
 
