@@ -1,10 +1,15 @@
 package Code::TidyAll::Plugin::PerlCritic;
 
+use strict;
+use warnings;
+
 use IPC::Run3 qw(run3);
+
 use Moo;
+
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 
 sub _build_cmd {'perlcritic'}
 
@@ -33,7 +38,7 @@ Code::TidyAll::Plugin::PerlCritic - Use perlcritic with tidyall
 
 =head1 VERSION
 
-version 0.52
+version 0.53
 
 =head1 SYNOPSIS
 
