@@ -1,11 +1,16 @@
 package Code::TidyAll::Plugin::PerlTidySweet;
 
+use strict;
+use warnings;
+
 use Capture::Tiny qw(capture_merged);
 use Perl::Tidy::Sweetened 1.00;
+
 use Moo;
+
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 
 sub transform_source {
     my ( $self, $source ) = @_;
@@ -49,7 +54,7 @@ Code::TidyAll::Plugin::PerlTidySweet - Use perltidy-sweet with tidyall
 
 =head1 VERSION
 
-version 0.52
+version 0.53
 
 =head1 SYNOPSIS
 
