@@ -1,10 +1,15 @@
 package Code::TidyAll::Plugin::PodChecker;
 
+use strict;
+use warnings;
+
 use Pod::Checker;
+
 use Moo;
+
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 
 has 'warnings' => ( is => 'ro' );
 
@@ -38,7 +43,7 @@ Code::TidyAll::Plugin::PodChecker - Use podchecker with tidyall
 
 =head1 VERSION
 
-version 0.52
+version 0.53
 
 =head1 SYNOPSIS
 
