@@ -1,15 +1,19 @@
 package Code::TidyAll::Plugin::PodSpell;
 
+use strict;
+use warnings;
+
 use Capture::Tiny qw();
-use IPC::System::Simple qw();
 use IPC::Run3;
 use List::SomeUtils qw(uniq);
 use Pod::Spell;
-use Moo;
 use Text::ParseWords qw(shellwords);
+
+use Moo;
+
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 
 has 'ispell_argv' => ( is => 'ro', default => q{} );
 has 'ispell_cmd'  => ( is => 'ro', default => 'ispell' );
@@ -61,7 +65,7 @@ Code::TidyAll::Plugin::PodSpell - Use Pod::Spell + ispell with tidyall
 
 =head1 VERSION
 
-version 0.52
+version 0.53
 
 =head1 SYNOPSIS
 
