@@ -1,11 +1,16 @@
 package Code::TidyAll::Plugin::PodTidy;
 
+use strict;
+use warnings;
+
 use Capture::Tiny qw(capture_merged);
 use Pod::Tidy;
+
 use Moo;
+
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 
 has 'columns' => ( is => 'ro' );
 
@@ -40,7 +45,7 @@ Code::TidyAll::Plugin::PodTidy - Use podtidy with tidyall
 
 =head1 VERSION
 
-version 0.52
+version 0.53
 
 =head1 SYNOPSIS
 
