@@ -1,9 +1,13 @@
 package Code::TidyAll::Plugin::SortLines;
 
+use strict;
+use warnings;
+
 use Moo;
+
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 
 sub transform_source {
     my ( $self, $source ) = @_;
@@ -27,7 +31,7 @@ Code::TidyAll::Plugin::SortLines - Sort the lines in a file
 
 =head1 VERSION
 
-version 0.52
+version 0.53
 
 =head1 SYNOPSIS
 
