@@ -1,8 +1,11 @@
 package Code::TidyAll::Result;
 
+use strict;
+use warnings;
+
 use Moo;
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 
 has 'error'         => ( is => 'ro' );
 has 'new_contents'  => ( is => 'ro' );
@@ -28,7 +31,7 @@ Code::TidyAll::Result - Result returned from processing a file/source
 
 =head1 VERSION
 
-version 0.52
+version 0.53
 
 =head1 SYNOPSIS
 
