@@ -1,10 +1,13 @@
 package Code::TidyAll::Role::Tempdir;
 
+use strict;
+use warnings;
+
 use Moo::Role;
 
 use Path::Tiny qw(tempdir);
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 
 has '_tempdir'   => ( is => 'ro', lazy => 1, builder => 1 );
 has 'no_cleanup' => ( is => 'ro', default => 0 );
@@ -34,7 +37,7 @@ classes
 
 =head1 VERSION
 
-version 0.52
+version 0.53
 
 =head1 SYNOPSIS
 
