@@ -1,15 +1,19 @@
 package Code::TidyAll::SVN::Precommit;
 
+use strict;
+use warnings;
+
 use Capture::Tiny qw(capture_stdout capture_stderr);
-use Code::TidyAll;
 use Code::TidyAll::Util qw(tempdir_simple);
+use Code::TidyAll;
 use Log::Any qw($log);
-use Moo;
 use Path::Tiny qw(path);
 use SVN::Look;
 use Try::Tiny;
 
-our $VERSION = '0.52';
+use Moo;
+
+our $VERSION = '0.53';
 
 # Public
 has 'conf_name'                => ( is => 'ro' );
@@ -179,7 +183,7 @@ to be tidyall'd
 
 =head1 VERSION
 
-version 0.52
+version 0.53
 
 =head1 SYNOPSIS
 
