@@ -1,19 +1,22 @@
 package Code::TidyAll::Util;
 
+use strict;
+use warnings;
+
 # These are loaded aned exported purely for backwards compat since some of Jon
 # Swartz's plugins use these in their tests :(
 use File::Basename qw(dirname);
 use File::Path qw(mkpath);
 use File::Slurp::Tiny qw(read_file write_file);
 
+use File::Spec;
 use Guard;
-use Path::Tiny qw(cwd tempdir);
+use Path::Tiny 0.098 qw(cwd path tempdir);
 use Try::Tiny;
-use strict;
-use warnings;
-use base qw(Exporter);
 
-our $VERSION = '0.52';
+use Exporter qw(import);
+
+our $VERSION = '0.53';
 
 our @EXPORT_OK = qw(can_load pushd tempdir_simple dirname mkpath read_file write_file);
 
@@ -43,7 +46,12 @@ sub can_load {
 
 sub tempdir_simple {
     my $template = shift || 'Code-TidyAll-XXXX';
-    return tempdir( $template, CLEANUP => 1 );
+
+    return tempdir(
+        { realpath => 1 },
+        TEMPLATE => $template,
+        CLEANUP  => 1
+    );
 }
 
 sub pushd {
