@@ -1,15 +1,19 @@
 package Test::Code::TidyAll;
 
+use strict;
+use warnings;
+
 use Code::TidyAll;
 use List::Compare;
 use Test::Builder;
+
+# Text::Diff has to be loaded before ::Table
 use Text::Diff;
 use Text::Diff::Table;
-use strict;
-use warnings;
-use base qw(Exporter);
 
-our $VERSION = '0.52';
+use Exporter qw(import);
+
+our $VERSION = '0.53';
 
 my $test = Test::Builder->new;
 
@@ -91,7 +95,7 @@ tidyall
 
 =head1 VERSION
 
-version 0.52
+version 0.53
 
 =head1 SYNOPSIS
 
